"use strict";
require("jasmine");
var path = require("path");
var filematcher_1 = require("../lib/filematcher");
var predicateoperator_1 = require("../lib/enums/predicateoperator");
var attributetype_1 = require("../lib/enums/attributetype");
describe('FileMatcher Tests', function () {
    var appPath = path.resolve(__dirname, '../../../test/sandbox');
    var finder;
    beforeAll(function (done) {
        finder = new filematcher_1.FileMatcher();
        done();
    });
    /*
     * Simple search by filename using globs.
     */
    it('Should return the .js files but not the .txt files', function (done) {
        finder.find({
            path: appPath,
            fileFilter: {
                fileNamePattern: ['**/*.js', '!**/*.spec.js']
            },
            recursiveSearch: true
        }).then(function (files) {
            expect(files.length).toBeGreaterThan(0);
            done();
        }).catch(function (err) {
            console.log('Error: ', err);
            done();
        });
    });
    /*
     * Search without glob array
     */
    it('Should return the .txt file only', function (done) {
        finder.find({
            path: appPath,
            fileFilter: {
                fileNamePattern: '**/*.txt'
            },
            recursiveSearch: true
        }).then(function (files) {
            expect(files.length).toBeGreaterThan(0);
            done();
        }).catch(function (err) {
            console.log('Error: ', err);
            done();
        });
    });
    /*
     * Filter by content matching only
     */
    it('Should filter by content only', function (done) {
        finder.find({
            path: appPath,
            fileFilter: {
                content: /right/i
            },
            recursiveSearch: true
        }).then(function (files) {
            expect(files.length).toBeGreaterThan(0);
            done();
        }).catch(function (err) {
            console.log('Error: ', err);
            done();
        });
    });
    /*
     * Search by filename and file content
     */
    it('Should filter .txt files and content choosealicense.com', function (done) {
        finder.find({
            path: appPath,
            fileFilter: {
                fileNamePattern: ['**/*.txt'],
                content: /choosealicense\.com/i,
            },
            recursiveSearch: true
        }).then(function (files) {
            expect(files.length).toBeGreaterThan(0);
            done();
        }).catch(function (err) {
            console.log('Error: ', err);
            done();
        });
    });
    /*
     * Search file by modified time
     */
    it('Should filter files by birth time', function (done) {
        finder.find({
            path: appPath,
            fileFilter: {
                attributeFilters: [
                    {
                        type: attributetype_1.AttributeType.BirthDate,
                        value: new Date(1900, 0, 1),
                        operator: predicateoperator_1.PredicateOperator.LessThan
                    }
                ]
            },
            recursiveSearch: true
        }).then(function (files) {
            expect(files.length).toBe(0);
            done();
        }).catch(function (err) {
            console.log('Error: ', err);
            done();
        });
    });
    /*
     * Search file by modified time
     */
    it('Should filter files by modified time', function (done) {
        finder.find({
            path: appPath,
            fileFilter: {
                attributeFilters: [
                    {
                        type: attributetype_1.AttributeType.ModifiedDate,
                        value: new Date(1900, 0, 1),
                        operator: predicateoperator_1.PredicateOperator.LessThan
                    }
                ]
            },
            recursiveSearch: true
        }).then(function (files) {
            expect(files.length).toBe(0);
            done();
        }).catch(function (err) {
            console.log('Error: ', err);
            done();
        });
    });
    /*
     * Search file by size, equal 0, meaning that the file
     * is empty.
     */
    it('Should find files with 0 bytes', function (done) {
        finder.find({
            path: appPath,
            fileFilter: {
                attributeFilters: [
                    {
                        type: attributetype_1.AttributeType.Size,
                        value: 0,
                        operator: predicateoperator_1.PredicateOperator.Equal
                    }
                ]
            },
            recursiveSearch: true
        }).then(function (files) {
            expect(files.length).toBeGreaterThan(0);
            done();
        }).catch(function (err) {
            console.log('Error: ', err);
            done();
        });
    });
    /*
     * Search file by size, equal 0, meaning that the file
     * is empty.
     */
    it('Should find files with more than 0 bytes', function (done) {
        finder.find({
            path: appPath,
            fileFilter: {
                attributeFilters: [
                    {
                        type: attributetype_1.AttributeType.Size,
                        value: 0,
                        operator: predicateoperator_1.PredicateOperator.NotEqual
                    }
                ]
            },
            recursiveSearch: true
        }).then(function (files) {
            done();
        }).catch(function (err) {
            expect(err).toBeDefined();
            done();
        });
    });
    /*
     * Should result in error, if no filters declared.
     */
    it('Should result in error, if no filters declared.', function (done) {
        finder.find({
            path: appPath,
            fileFilter: {}
        }).then(function (files) {
            expect('It shouldnt be here!').toBeUndefined();
            done();
        }).catch(function (err) {
            expect(err).toBeDefined();
            done();
        });
    });
    /*
     * Should result in error, if the path is a clear string
     */
    it('Should result in error, if the path is a clear string', function (done) {
        finder.find({
            path: '',
            fileFilter: {}
        }).then(function (files) {
            expect('It shouldnt be here!').toBeUndefined();
            done();
        }).catch(function (err) {
            expect(err).toBeDefined();
            done();
        });
    });
    /*
     * Should result in error, if the path is a string with spaces.
     */
    it('Should result in error, if the path is a string with spaces.', function (done) {
        finder.find({
            path: ' ',
            fileFilter: {
                fileNamePattern: ['**/*.js']
            }
        }).then(function (files) {
            expect('It shouldnt be here!').toBeUndefined();
            done();
        }).catch(function (err) {
            expect(err).toBeDefined();
            done();
        });
    });
    /*
     * Should result in error, if there is no attribute filters and content regex.
     */
    it('Should result in error, if there is no attribute filters and content regex.', function (done) {
        finder.find({
            path: appPath,
            fileFilter: {
                attributeFilters: []
            }
        }).then(function (files) {
            expect('It shouldnt be here!').toBeUndefined();
            done();
        }).catch(function (err) {
            expect(err).toBeDefined();
            done();
        });
    });
    /*
     * Should result in error, for reading an image file.
     */
    it('Should result in error as the directory not exists', function (done) {
        finder.find({
            path: 'directory/should/not/exists',
            fileFilter: {
                fileNamePattern: ['**/.txt']
            },
        }).then(function (files) {
            expect('It shouldnt be here!').toBeUndefined();
            done();
        }).catch(function (err) {
            expect(err).toBeDefined();
            done();
        });
    });
    /*
     * Should result in error, for reading an xml file without write permission.
     */
    it('Should result in error for the lack of write permission.', function (done) {
        finder.find({
            path: appPath,
            fileFilter: {
                fileNamePattern: ['**/*.xml'],
                content: /may/i,
                fileReadOptions: { encoding: 'utf8', flag: 'w' }
            },
            recursiveSearch: true,
        }).then(function (files) {
            console.log(files);
            expect(files.length).toBe(0);
            done();
        }).catch(function (err) {
            expect(err).toBeDefined();
            done();
        });
    });
    /*
     * Search file by size, equal 0, meaning that the file
     * is empty.
     */
    it('Should not bring files with .txt extension', function (done) {
        finder.find({
            path: appPath,
            fileFilter: {
                fileNamePattern: '!**/*.txt'
            },
            recursiveSearch: true
        }).then(function (files) {
            var matched = false;
            files.some(function (file) {
                return matched = file.indexOf('.txt') > -1;
            });
            expect(matched).toBeFalsy();
            done();
        }).catch(function (err) {
            console.log('Error: ', err);
            done();
        });
    });
    /*
     * Search file by size (bytes), testing the GreaterThan operator.
     */
    it('Should filter files by size, testing the GreaterThan operator.', function (done) {
        finder.find({
            path: appPath,
            fileFilter: {
                attributeFilters: [
                    {
                        type: attributetype_1.AttributeType.Size,
                        value: 10,
                        operator: predicateoperator_1.PredicateOperator.GreaterThan
                    }
                ]
            },
            recursiveSearch: true
        }).then(function (files) {
            expect(files.length).toBeGreaterThan(0);
            done();
        }).catch(function (err) {
            console.log('Error: ', err);
            done();
        });
    });
    /*
     * Search file by filters and content
     */
    it('Should filter files by filters (pattern and size) and content', function (done) {
        finder.find({
            path: appPath,
            fileFilter: {
                fileNamePattern: ['**/*.txt'],
                content: /(lic)/i,
                attributeFilters: [
                    {
                        type: attributetype_1.AttributeType.Size,
                        value: 10,
                        operator: predicateoperator_1.PredicateOperator.GreaterThan
                    }
                ]
            },
            recursiveSearch: true
        }).then(function (files) {
            expect(files.length).toBe(1);
            done();
        }).catch(function (err) {
            console.log('Error: ', err);
            done();
        });
    });
    /*
     * Search file not recursively
     */
    it('Should filter files not recursively', function (done) {
        finder.find({
            path: appPath,
            fileFilter: {
                fileNamePattern: ['**/**', '!*.spec.js'],
                content: /(lic)/i
            },
            recursiveSearch: false
        }).then(function (files) {
            expect(files.length).toBe(0);
            done();
        }).catch(function (err) {
            console.log('Error: ', err);
            done();
        });
    });
});
//# sourceMappingURL=filematcher.spec.js.map